@@ -8,7 +8,8 @@ from linora.image._image_resize import *
 from linora.image._image_rescale import *
 from linora.image._image_util import *
 from linora.image._image_filter import *
-from linora.image._image_combination import *
+from linora.image._image_pairs import *
 from linora.image._image_feature import *
 from linora.image._image_draw import *
-from linora.image._image_rgb import *
\ No newline at end of file
+from linora.image._image_rgb import *
+from linora.image._image_box import *
\ No newline at end of file
