@@ -1,10 +1,12 @@
 # from linora.param_search import GEClassifier
 # from linora.param_search import GERegressor
-# from linora.param_search import LGBClassifier
+from linora.param_search import LGBMClassifier
+from linora.param_search import LGBMRegressor
 from linora.param_search import XGBClassifier
-# from linora.param_search import XGBRanker
 from linora.param_search import XGBRegressor
+# from linora.param_search import XGBRanker
 
 from linora.param_search._HyperParameters import *
 
-from linora.param_search._config import __xgboost_version__
+from linora.param_search._config import __xgboost_version__, __lightgbm_version__
+
